import { useSize } from "ahooks";
import React, { useRef, useState, useCallback, useEffect } from "react"
import Table, { BaseTableProps, Column, ColumnShape, SortOrder } from 'react-base-table'
import 'react-base-table/styles.css'
import './index.less'
import { Empty, Pagination, Spin } from "antd";
import { PaginationProps } from "antd/es/pagination";

interface Props extends Omit<BaseTableProps, 'width'> {
    isPagination?: boolean,
    pagination?: PaginationProps
    width?: number
    loading?: boolean
    onChange?: (data: {
        pagination?: { current?: number, pageSize?: number, gzh?: string },
        sortData?: { column: ColumnShape<unknown>, field: React.Key, order: "ascend" | "descend" }
    }) => void
}
const BaseTable: React.FC<Props> = ({ isPagination = true, pagination, width, height, estimatedRowHeight, rowHeight, fixed, columns, loading, onChange, ...props }) => {

    /***************************************/
    const ref = useRef(null);
    const tableRef = useRef(null);
    const size = useSize(ref);
    const [operate, setOperate] = useState<{
        pagination?: { current?: number, pageSize?: number },
        sortData?: { column: ColumnShape<unknown>, key: React.Key, order: SortOrder }
    }>({})
    /***************************************/

    useEffect(() => {
        setOperate({ ...operate, pagination: { current: pagination?.current || 1, pageSize: pagination?.pageSize || pagination?.defaultPageSize || 20 } })
    }, [pagination?.current, pagination?.pageSize, pagination?.defaultPageSize])

    // let columns: ColumnShape<any>[] = [
    //     {
    //         key: 'name',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //         frozen: Column.FrozenDirection.LEFT,
    //     },
    //     {
    //         key: 'score',
    //         title: 'Score',
    //         dataKey: 'score.math',
    //         width: 60,
    //         align: Column.Alignment.CENTER,
    //         sortable: false,
    //     },
    //     {
    //         key: 'gender',
    //         title: '♂♀',
    //         dataKey: 'gender',
    //         width: 60,
    //         align: Column.Alignment.CENTER,
    //         sortable: true,
    //     },
    //     {
    //         key: 'birthday',
    //         title: 'Birthday',
    //         dataKey: 'birthday',
    //         width: 100,
    //         align: Column.Alignment.RIGHT,
    //         sortable: true,
    //     },
    //     {
    //         key: 'email',
    //         title: 'Email',
    //         dataKey: 'email',
    //         width: 200,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'country',
    //         title: 'Country',
    //         dataKey: 'country',
    //         width: 100,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'address',
    //         title: 'Address',
    //         dataKey: 'address.street',
    //         width: 200,
    //         resizable: true,
    //     },
    //     {
    //         key: 'name1',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'name2',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'name3',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'name4',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'name5',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'name6',
    //         title: 'Name',
    //         dataKey: 'name',
    //         width: 150,
    //         resizable: true,
    //         sortable: true,
    //     },
    //     {
    //         key: 'description',
    //         title: 'Description',
    //         dataKey: 'description',
    //         width: 200,
    //         resizable: true,
    //         sortable: true,
    //         cellRenderer: ({ rowData, cellData }: any) => (
    //             <a
    //                 onClick={() => {
    //                     console.log(rowData, cellData)
    //                 }}
    //             >
    //                 Remove
    //             </a>
    //         ),
    //     },
    //     // {
    //     //     title: '操作',
    //     //     key: 'action',
    //     //     width: 100,
    //     //     align: Column.Alignment.CENTER,
    //     //     frozen: Column.FrozenDirection.RIGHT,

    //     //     cellRenderer: ({ rowData, cellData }: any) => (
    //     //         <button
    //     //             onClick={() => {
    //     //                 console.log(rowData, cellData)
    //     //             }}
    //     //         >
    //     //             Remove
    //     //         </button>
    //     //     ),
    //     // },
    // ]

    // const defaultData = Array.from({ length: 10000 }, (_, key) => ({
    //     id: key,
    //     name: 'row' + key,
    //     gender: '男',
    //     score: {
    //         math: 30,
    //     },
    //     birthday: 222,
    //     attachments: 111,
    //     email: '7787@qq.com',
    //     country: '22',
    //     description: '11',
    // }));

    let tableProps: BaseTableProps = {
        fixed: fixed || true,  // 是否开启 列的宽度是固定的还是灵活的
        // columns,               // 表的列
        // data: defaultData,     // 表数据
        width: width || size.width || 900,  // 表固定宽度
        height: height || 600,              // 表固定高度
    }
    if (estimatedRowHeight) {
        tableProps.estimatedRowHeight = estimatedRowHeight   // 灵活高度
        if (props?.data?.length < 10) {
            tableProps.maxHeight = 600
        }
    } else {
        tableProps.rowHeight = rowHeight || 26               // 固定高度
        if (props?.data?.length < 20) {
            tableProps.maxHeight = 600
        }
    }

    if (columns) {
        let totalWidth = columns.reduce((pre: number, cur: { width: number; }) => {
            pre += cur.width
            return pre
        }, 0)
        if (totalWidth < tableProps.width) {
            let length = columns?.length || 1
            let diffW = (tableProps.width - totalWidth - 6) / length

            columns = columns.map((item: any) => {
                return { ...item, width: item.width + diffW }
            })
        }
    }
    if (!props?.data || props?.data?.length === 0) {
        delete tableProps.maxHeight
        tableProps.height = 200
    }

    tableProps.columns = columns

    tableProps = { ...tableProps, ...props }

    // 排序操作
    const onColumnSort = useCallback((sortBy: { column: ColumnShape<unknown>, key: React.Key, order: SortOrder }) => {
        const { key, order } = sortBy;
        let newOperate = JSON.parse(JSON.stringify(operate))
        const sortData = newOperate?.sortData
        if (sortData && sortData.key === key) {
            if (order === 'asc') {
                newOperate = { ...newOperate, sortData: undefined } // 取消排序
            } else {
                newOperate = { ...newOperate, sortData: sortBy }
            }
        } else {
            newOperate = { ...newOperate, sortData: sortBy }
        }
        setOperate(newOperate)
        onChange?.({ ...newOperate, sortData: newOperate?.sortData ? { ...newOperate.sortData, field: newOperate.sortData.key, order: newOperate.sortData.order === 'asc' ? 'ascend' : 'descend' } : undefined })
    }, [operate])

    return <Spin spinning={loading}>
        <div ref={ref}>
            <Table
                ref={tableRef}
                overscanRowCount={2}
                emptyRenderer={<Empty image={Empty.PRESENTED_IMAGE_SIMPLE} />}
                sortBy={operate?.sortData}
                onColumnSort={onColumnSort}
                {...tableProps}
            />
            {isPagination && <div className="pagination">
                <Pagination 
                    onChange={(page: number, pageSize: number) => {
                        setOperate({...operate, pagination: { current: page, pageSize }});
                        onChange?.({ ...operate, pagination: { current: page, pageSize }, sortData: operate?.sortData ? { ...operate.sortData, field: operate.sortData.key, order: operate.sortData.order === 'asc' ? 'ascend' : 'descend' } : undefined });
                        (tableRef.current as any)?.scrollToTop(0)
                    }} 
                    {...pagination} 
                />
            </div>}
        </div>
    </Spin>
}

export default React.memo(BaseTable)